@@ -45,9 +45,9 @@ def parse(url):
     # Update with environment configuration.
     config.update({
         "DB": int(path or 0),
-        "PASSWORD": url.password,
-        "HOST": url.hostname,
-        "PORT": url.port,
+        "PASSWORD": url.password or None,
+        "HOST": url.hostname or "localhost",
+        "PORT": int(url.port or 6379),
     })
 
     return config
